/*******************************************************************************
* File Name: AMux_CDS.h
* Version 1.80
*
*  Description:
*    This file contains the constants and function prototypes for the Analog
*    Multiplexer User Module AMux.
*
*   Note:
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_AMUX_AMux_CDS_H)
#define CY_AMUX_AMux_CDS_H

#include "cyfitter.h"
#include "cyfitter_cfg.h"

#if ((CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3) || \
         (CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC4) || \
         (CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC5))    
    #include "cytypes.h"
#else
    #include "syslib/cy_syslib.h"
#endif /* ((CYDEV_CHIP_FAMILY_USED == CYDEV_CHIP_FAMILY_PSOC3) */


/***************************************
*        Function Prototypes
***************************************/

void AMux_CDS_Start(void) ;
#define AMux_CDS_Init() AMux_CDS_Start()
void AMux_CDS_FastSelect(uint8 channel) ;
/* The Stop, Select, Connect, Disconnect and DisconnectAll functions are declared elsewhere */
/* void AMux_CDS_Stop(void); */
/* void AMux_CDS_Select(uint8 channel); */
/* void AMux_CDS_Connect(uint8 channel); */
/* void AMux_CDS_Disconnect(uint8 channel); */
/* void AMux_CDS_DisconnectAll(void) */


/***************************************
*         Parameter Constants
***************************************/

#define AMux_CDS_CHANNELS  2u
#define AMux_CDS_MUXTYPE   2
#define AMux_CDS_ATMOSTONE 1

/***************************************
*             API Constants
***************************************/

#define AMux_CDS_NULL_CHANNEL 0xFFu
#define AMux_CDS_MUX_SINGLE   1
#define AMux_CDS_MUX_DIFF     2


/***************************************
*        Conditional Functions
***************************************/

#if AMux_CDS_MUXTYPE == AMux_CDS_MUX_SINGLE
# if !AMux_CDS_ATMOSTONE
#  define AMux_CDS_Connect(channel) AMux_CDS_Set(channel)
# endif
# define AMux_CDS_Disconnect(channel) AMux_CDS_Unset(channel)
#else
# if !AMux_CDS_ATMOSTONE
void AMux_CDS_Connect(uint8 channel) ;
# endif
void AMux_CDS_Disconnect(uint8 channel) ;
#endif

#if AMux_CDS_ATMOSTONE
# define AMux_CDS_Stop() AMux_CDS_DisconnectAll()
# define AMux_CDS_Select(channel) AMux_CDS_FastSelect(channel)
void AMux_CDS_DisconnectAll(void) ;
#else
# define AMux_CDS_Stop() AMux_CDS_Start()
void AMux_CDS_Select(uint8 channel) ;
# define AMux_CDS_DisconnectAll() AMux_CDS_Start()
#endif

#endif /* CY_AMUX_AMux_CDS_H */


/* [] END OF FILE */
